==> hyperkyc_flutter-0.3.0.tar.gz: lib/hyperkyc_result.dart <==
import 'package:hyperkyc_flutter/hyperkyc_flutter_constants.dart';

/// [HyperKycStatus] enum will state whether the hyperkyc flow was [autoApproved] or [autoDeclined] or [manuallyApproved] or [manuallyDeclined] or [ongoing] or [needsReview] or [userCancelled] or [error]
enum HyperKycStatus {
  /// Auto Approved state
  autoApproved,

  /// Auto Declined state
  autoDeclined,

  /// Manually Approved state
  manuallyApproved,

  /// Manually Declined state
  manuallyDeclined,

  /// Ongoing state
  ongoing,

  /// Needs Review state
  needsReview,

  /// User Cancelled state
  userCancelled,

  /// Error state
  error,
}

/// [HyperKycStatusExtension]
extension HyperKycStatusExtension on HyperKycStatus {
  String get value {
    switch (this) {
      case HyperKycStatus.autoApproved:
        return HyperKycConstants.autoApproved;
      case HyperKycStatus.autoDeclined:
        return HyperKycConstants.autoDeclined;
      case HyperKycStatus.manuallyApproved:
        return HyperKycConstants.manuallyApproved;
      case HyperKycStatus.manuallyDeclined:
        return HyperKycConstants.manuallyDeclined;
      case HyperKycStatus.ongoing:
        return HyperKycConstants.ongoing;
      case HyperKycStatus.needsReview:
        return HyperKycConstants.needsReview;
      case HyperKycStatus.userCancelled:
        return HyperKycConstants.userCancelled;
      case HyperKycStatus.error:
        return HyperKycConstants.error;
    }
  }
}

/// [HyperKycResult] contains the result from the HyperKyc workflow
class HyperKycResult {
  /// State whether the hyperkyc flow was success or cancelled or failure.
  final HyperKycStatus? status;

  /// [transactionId] used for the flow
  final String? transactionId;

  /// [details] will containSDK response
  final Map<dynamic, dynamic>? details;

  /// State [errorCode] of error occurred during the hyperkyc flow
  final int? errorCode;

  /// State [errorMessage] of error occurred during the hyperkyc flow
  final String? errorMessage;

  /// State [latestModule] of the module when error occurred during the hyperkyc flow
  final String? latestModule;

  /// Constructor
  HyperKycResult({
    this.status,
    this.transactionId,
    this.details,
    this.errorCode,
    this.errorMessage,
    this.latestModule,
  });

  /// Convert HyperKycResult object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.status: status,
      HyperKycConstants.transactionId: transactionId,
      HyperKycConstants.details: details,
      HyperKycConstants.errorCode: errorCode,
      HyperKycConstants.errorMessage: errorMessage,
      HyperKycConstants.latestModule: latestModule,
    };
  }

  /// Convert map to HyperKycResult object
  factory HyperKycResult.fromMap(Map<dynamic, dynamic> json) {
    HyperKycStatus hyperKycStatus = HyperKycStatus.autoDeclined;
    switch (json[HyperKycConstants.status]) {
      case HyperKycConstants.autoApproved:
        hyperKycStatus = HyperKycStatus.autoApproved;
        break;
      case HyperKycConstants.autoDeclined:
        hyperKycStatus = HyperKycStatus.autoDeclined;
        break;
      case HyperKycConstants.manuallyApproved:
        hyperKycStatus = HyperKycStatus.manuallyApproved;
        break;
      case HyperKycConstants.manuallyDeclined:
        hyperKycStatus = HyperKycStatus.manuallyDeclined;
        break;
      case HyperKycConstants.ongoing:
        hyperKycStatus = HyperKycStatus.ongoing;
        break;
      case HyperKycConstants.needsReview:
        hyperKycStatus = HyperKycStatus.needsReview;
        break;
      case HyperKycConstants.userCancelled:
        hyperKycStatus = HyperKycStatus.userCancelled;
        break;
      case HyperKycConstants.error:
        hyperKycStatus = HyperKycStatus.error;
        break;
    }

    int? errorCode;
    if (json[HyperKycConstants.errorCode] != -1000) {
      errorCode = json[HyperKycConstants.errorCode];
    }

    return HyperKycResult(
      status: hyperKycStatus,
      transactionId: json[HyperKycConstants.transactionId] as String?,
      details: (json[HyperKycConstants.details] ?? {}),
      errorCode: errorCode,
      errorMessage: json[HyperKycConstants.errorMessage] as String?,
      latestModule: json[HyperKycConstants.latestModule] as String?,
    );
  }

  /// Overridden [toString] method
  @override
  String toString() {
    return 'HyperKycResult{status: $status, transactionId: $transactionId, details: $details, errorCode: $errorCode, errorMessage: $errorMessage, latestModule: $latestModule}';
  }
}

==> hyperkyc_flutter-0.19.0.tar.gz: lib/hyperkyc_result.dart <==
import 'package:hyperkyc_flutter/hyperkyc_flutter_constants.dart';

/// [HyperKycStatus] enum will state whether the hyperkyc flow was [autoApproved] or [autoDeclined] or [manuallyApproved] or [manuallyDeclined] or [ongoing] or [needsReview] or [userCancelled] or [error]
enum HyperKycStatus {
  /// Auto Approved state
  autoApproved,

  /// Auto Declined state
  autoDeclined,

  /// Manually Approved state
  manuallyApproved,

  /// Manually Declined state
  manuallyDeclined,

  /// Ongoing state
  ongoing,

  /// Needs Review state
  needsReview,

  /// User Cancelled state
  userCancelled,

  /// Error state
  error,
}

/// [HyperKycStatusExtension]
extension HyperKycStatusExtension on HyperKycStatus {
  String get value {
    switch (this) {
      case HyperKycStatus.autoApproved:
        return HyperKycConstants.autoApproved;
      case HyperKycStatus.autoDeclined:
        return HyperKycConstants.autoDeclined;
      case HyperKycStatus.manuallyApproved:
        return HyperKycConstants.manuallyApproved;
      case HyperKycStatus.manuallyDeclined:
        return HyperKycConstants.manuallyDeclined;
      case HyperKycStatus.ongoing:
        return HyperKycConstants.ongoing;
      case HyperKycStatus.needsReview:
        return HyperKycConstants.needsReview;
      case HyperKycStatus.userCancelled:
        return HyperKycConstants.userCancelled;
      case HyperKycStatus.error:
        return HyperKycConstants.error;
    }
  }
}

/// [HyperKycResult] contains the result from the HyperKyc workflow
class HyperKycResult {
  /// State whether the hyperkyc flow was success or cancelled or failure.
  final HyperKycStatus? status;

  /// [transactionId] used for the flow
  final String? transactionId;

  /// [details] will containSDK response
  final Map<dynamic, dynamic>? details;

  /// State [errorCode] of error occurred during the hyperkyc flow
  final int? errorCode;

  /// State [errorMessage] of error occurred during the hyperkyc flow
  final String? errorMessage;

  /// State [latestModule] of the module when error occurred during the hyperkyc flow
  final String? latestModule;

  /// Complete response dump which will be used in HyperKyc demo app only (Demo purpose only)
  String? _rawDataJsonString;

  /// Constructor
  HyperKycResult({
    this.status,
    this.transactionId,
    this.details,
    this.errorCode,
    this.errorMessage,
    this.latestModule,
    String? rawDataJsonString,
  }) {
    _rawDataJsonString = rawDataJsonString;
  }

  /// Convert HyperKycResult object to Map - Exclude #rawDataJsonString from [toMap]
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.status: status,
      HyperKycConstants.transactionId: transactionId,
      HyperKycConstants.details: details,
      HyperKycConstants.errorCode: errorCode,
      HyperKycConstants.errorMessage: errorMessage,
      HyperKycConstants.latestModule: latestModule,
    };
  }

  /// Convert map to HyperKycResult object
  factory HyperKycResult.fromMap(Map<dynamic, dynamic> json) {
    HyperKycStatus hyperKycStatus = HyperKycStatus.autoDeclined;
    switch (json[HyperKycConstants.status]) {
      case HyperKycConstants.autoApproved:
        hyperKycStatus = HyperKycStatus.autoApproved;
        break;
      case HyperKycConstants.autoDeclined:
        hyperKycStatus = HyperKycStatus.autoDeclined;
        break;
      case HyperKycConstants.manuallyApproved:
        hyperKycStatus = HyperKycStatus.manuallyApproved;
        break;
      case HyperKycConstants.manuallyDeclined:
        hyperKycStatus = HyperKycStatus.manuallyDeclined;
        break;
      case HyperKycConstants.ongoing:
        hyperKycStatus = HyperKycStatus.ongoing;
        break;
      case HyperKycConstants.needsReview:
        hyperKycStatus = HyperKycStatus.needsReview;
        break;
      case HyperKycConstants.userCancelled:
        hyperKycStatus = HyperKycStatus.userCancelled;
        break;
      case HyperKycConstants.error:
        hyperKycStatus = HyperKycStatus.error;
        break;
    }

    int? errorCode;
    if (json[HyperKycConstants.errorCode] != -1000) {
      errorCode = json[HyperKycConstants.errorCode];
    }

    return HyperKycResult(
      status: hyperKycStatus,
      transactionId: json[HyperKycConstants.transactionId] as String?,
      details: (json[HyperKycConstants.details] ?? {}),
      errorCode: errorCode,
      errorMessage: json[HyperKycConstants.errorMessage] as String?,
      latestModule: json[HyperKycConstants.latestModule] as String?,
      rawDataJsonString: json[HyperKycConstants.rawDataJsonString] as String?,
    );
  }

  /// Overridden [toString] method - Exclude #rawDataJsonString from [toString]
  @override
  String toString() {
    return 'HyperKycResult{status: $status, transactionId: $transactionId, details: $details, errorCode: $errorCode, errorMessage: $errorMessage, latestModule: $latestModule}';
  }

  /// Obtain responseDump in HyperKyc demo app only (Demo purpose only)
  String? getRawDataJsonString() {
    return _rawDataJsonString;
  }
}
